@@ -1,10 +1,18 @@
+"""
+Module containing custom exceptions
+"""
+
+
 class CustomBaseException(Exception):
-    def __init__(self, msg):
-        self.msg = msg
-        super().__init__(msg)
+    """
+    Base exception for all other exceptions to inherit from
+    """
+    def __init__(self, message: str):
+        self.message = message
+        super().__init__(message)
 
     def __str__(self):
-        return self.msg
+        return self.message
 
 
 class AuthenticationError(CustomBaseException):
@@ -12,8 +20,8 @@ class AuthenticationError(CustomBaseException):
     Custom exception for authentication errors when interacting with the APIs
     """
 
-    def __init__(self, msg, *args, **kwargs):
-        super().__init__(msg)
+    def __init__(self, message: str, *args, **kwargs):
+        super().__init__(message)
 
 
 class ApiError(CustomBaseException):
@@ -21,8 +29,8 @@ class ApiError(CustomBaseException):
     Custom exception for non authentication related errors
     """
 
-    def __init__(self, msg, *args, **kwargs):
-        super().__init__(msg)
+    def __init__(self, message: str, *args, **kwargs):
+        super().__init__(message)
 
 
 class InvalidConfig(CustomBaseException):
