@@ -96,6 +96,7 @@ def authenticated_request(
                 The output of the wrapped function
             """
             config = env_config if env_config is not None else EnvironmentConfig()
+            headers = kwargs.get("headers", {})
 
             if config.auth_config.can_authenticate():
                 auth_headers = authenticate(
@@ -104,10 +105,9 @@ def authenticated_request(
                     password=config.auth_config.password,
                     token=config.auth_config.token
                 )
-                headers = kwargs.get("headers", {})
-                headers.update(auth_headers)
-                kwargs["headers"] = headers
-            else:
+                auth_headers.update(headers)  # override authentication header if already provided
+                kwargs["headers"] = auth_headers
+            elif headers.get("Authorization") is None:
                 error = AuthenticationError("Authentication for the package was configured incorrectly and is either "
                                             "missing a AUTH_TOKEN or ALGORA_USER and ALGORA_PWD environment variable(s)")
                 logger.error(error)
